@@ -1,17 +1,3 @@
-"""
-Copyright 2018-2020 Skyscanner Ltd
-
-Licensed under the Apache License, Version 2.0 (the "License"); you may not use
-this file except in compliance with the License.
-You may obtain a copy of the License at
-
-http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software distributed
-under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
-CONDITIONS OF ANY KIND, either express or implied. See the License for the
-specific language governing permissions and limitations under the License.
-"""
 import logging
 from abc import ABC, abstractmethod
 from typing import Dict, List, Optional, Set
@@ -64,9 +50,13 @@ class Rule(ABC):
         rule_mode = rule_mode or self.rule_mode
         risk_value = risk_value or self.risk_value
         for fltr in self.rule_config.filters:
-            if fltr(**context):
-                risk_value = fltr.risk_value or risk_value
-                rule_mode = fltr.rule_mode or rule_mode
+            try:
+                if fltr(**context):
+                    risk_value = fltr.risk_value or risk_value
+                    rule_mode = fltr.rule_mode or rule_mode
+            except Exception:
+                logger.exception(f"Exception raised while evaluating filter for `{fltr.reason}`", extra=context)
+
         if rule_mode not in (RuleMode.DISABLED, RuleMode.WHITELISTED):
             result.add_failure(
                 rule=type(self).__name__,
