@@ -1,17 +1,3 @@
-"""
-Copyright 2018-2020 Skyscanner Ltd
-
-Licensed under the Apache License, Version 2.0 (the "License"); you may not use
-this file except in compliance with the License.
-You may obtain a copy of the License at
-
-http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software distributed
-under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
-CONDITIONS OF ANY KIND, either express or implied. See the License for the
-specific language governing permissions and limitations under the License.
-"""
 __all__ = ["S3BucketPolicyPrincipalRule"]
 import logging
 from typing import Dict, Optional
@@ -19,7 +5,7 @@ from typing import Dict, Optional
 from pycfmodel.model.cf_model import CFModel
 from pycfmodel.model.resources.s3_bucket_policy import S3BucketPolicy
 
-from cfripper.model.enums import RuleGranularity, RuleMode, RuleRisk
+from cfripper.model.enums import RuleGranularity, RuleRisk
 from cfripper.model.result import Result
 from cfripper.model.utils import get_account_id_from_principal
 from cfripper.rules.base_rules import PrincipalCheckingRule
@@ -41,7 +27,6 @@ class S3BucketPolicyPrincipalRule(PrincipalCheckingRule):
 
     GRANULARITY = RuleGranularity.RESOURCE
     REASON = "S3 Bucket {} policy has non-whitelisted principals {}"
-    RULE_MODE = RuleMode.BLOCKING
     RISK_VALUE = RuleRisk.HIGH
 
     def invoke(self, cfmodel: CFModel, extras: Optional[Dict] = None) -> Result:
