@@ -1,17 +1,3 @@
-"""
-Copyright 2018-2020 Skyscanner Ltd
-
-Licensed under the Apache License, Version 2.0 (the "License"); you may not use
-this file except in compliance with the License.
-You may obtain a copy of the License at
-
-http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software distributed
-under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
-CONDITIONS OF ANY KIND, either express or implied. See the License for the
-specific language governing permissions and limitations under the License.
-"""
 __all__ = [
     "GenericWildcardPolicyRule",
     "S3BucketPolicyWildcardActionRule",
@@ -28,7 +14,7 @@ from pycfmodel.model.resources.sns_topic_policy import SNSTopicPolicy
 from pycfmodel.model.resources.sqs_queue_policy import SQSQueuePolicy
 
 from cfripper.config.regex import REGEX_HAS_STAR_OR_STAR_AFTER_COLON
-from cfripper.model.enums import RuleGranularity, RuleMode
+from cfripper.model.enums import RuleGranularity
 from cfripper.model.result import Result
 from cfripper.rules.base_rules import Rule
 
@@ -44,7 +30,6 @@ class GenericWildcardPolicyRule(Rule):
 
     REASON = "The {} {} should not allow a `*` action"
 
-    RULE_MODE = RuleMode.DEBUG
     GRANULARITY = RuleGranularity.RESOURCE
 
     AWS_RESOURCE: Type[Resource] = None
